<?php
/*
 * This file contains all the graphic functions that creates the user interfaces validator and submit functions
 */

/**
 * ****************************************************************************
 * ADMINISTRATION COMPONENTS -- Configuration from admin panel
 */

/**
 * Implements hook_admin() Drupal 7 function
 * Creates an administration panel for current (function name) form
 */
function fourdemnews_admin() {
	$form = array ();
	$form ['fld001'] = array (
			'#type' => 'fieldset',
			'#title' => t ( 'Connetcion Settings' ),
			'#weight' => 1,
			'#collapsible' => TRUE,
			'#collapsed' => FALSE 
	);
	
	$form ['fld003'] = array (
			'#type' => 'fieldset',
			'#title' => t ( 'Registered Users List' ),
			'#weight' => 10,
			'#collapsible' => TRUE,
			'#collapsed' => FALSE 
	);
	
	$form ['fld002'] = array (
			'#type' => 'fieldset',
			'#title' => t ( 'Newsletter Destination List' ),
			'#weight' => 20,
			'#collapsible' => TRUE,
			'#collapsed' => FALSE 
	);
	
	$form ['fld001'] ['fourdemConfig_username'] = array (
			'#type' => 'textfield',
			'#title' => t ( "Username" ),
			'#description' => t ( "4Dem username" ),
			'#default_value' => variable_get ( 'fourdemConfig_username', '' ),
			'#size' => 50 
	);
	
	$form ['fld001'] ['fourdemConfig_password'] = array (
			'#type' => 'textfield',
			'#title' => t ( "Password" ),
			'#description' => t ( "4Dem password" ),
			'#default_value' => variable_get ( 'fourdemConfig_password', '' ),
			'#size' => 50 
	);
	
	$form ['fld001'] ['fourdemConfig_url'] = array (
			'#type' => 'textfield',
			'#title' => t ( "Console URL" ),
			'#description' => t ( "4Dem console URL (i.e. http://mailchef.4dem.it)" ),
			'#default_value' => variable_get ( 'fourdemConfig_url', '' ),
			'#size' => 50 
	);
	
	$listeConsole = recuperaArrayListe ();
	if (count ( $listeConsole ) > 1) {
		$form ['fld003'] ['fourdemConfig_registered_listID'] = array (
				'#type' => 'select',
				'#weight' => 10,
				'#options' => $listeConsole,
				'#title' => t ( 'Select console destination list for registered users' ),
				'#default_value' => variable_get ( 'fourdemConfig_registered_listID', - 1 ) 
		);
		
		// Autosynch checkbox -- Start
		// If is checked drupal will send registered users to console automatically
		if (variable_get ( 'fourdemConfig_registered_listID', - 1 ) != - 1) {
			$form ['fld003'] ['fourdemConfig_Checkbox_AutoSynch'] = array (
					'#type' => 'checkbox',
					'#weight' => 5,
					'#title' => t ( 'Enable autosynch for registered users' ),
					'#default_value' => variable_get ( 'fourdemConfig_Checkbox_AutoSynch', 0 ) 
			);
		}
		// Autosynch checkbox -- End
		
		// Manual Synchro button -- Start
		// If a valid destination list has been selected, admin can start a manual synchronization
		if (variable_get ( 'fourdemConfig_registered_listID', - 1 ) != - 1) {
			$form ['fld003'] ['fourdemConfig_Button_Synch'] = array (
					'#type' => 'submit',
					'#weight' => 20,
					'#value' => t ( 'Synchronize Users Now!' ),
					'#submit' => array (
							'sincronizzaUtenti' 
					) 
			);
		}
		// Manual Synchro button -- End
		
		$form ['fld002'] ['fourdemConfig_newsletter_listID'] = array (
				'#type' => 'select',
				'#options' => $listeConsole,
				'#title' => t ( 'Select console destination list' ),
				'#default_value' => variable_get ( 'fourdemConfig_newsletter_listID', - 1 ) 
		);
	} else {
		
		$form ['fld003'] ['fourdemConfig_registered_text'] = array (
				'#type' => 'markup',
				'#markup' => "<i><b>" . t ( "Save configuration before select destination list!" ) . "</b></i>" 
		);
		
		$form ['fld002'] ['fourdemConfig_newsletter_text'] = array (
				'#type' => 'markup',
				'#markup' => "<i><b>" . t ( "Save configuration before select destination list!" ) . "</b></i>" 
		);
	}
	
	return system_settings_form ( $form );
} // function fourdemnews_admin()

/*
 * ******************************************************************************* FRONT END / BLOCKS ELEMENTS -- Define appearence and functions
 */

/**
 * Implementation of hook_form() Drupal 7 function - define the graphic layout of the form to be returned
 *
 * @param
 *        	<b>form</b>: which holds all of the elements of the form
 * @param
 *        	<b>form_state</b>: a special array of settings & values needed by Drupal
 */
function fourdemNewsletter_form($form, $form_state) {
	$form ['fourdemUser_email'] = array (
			// #type tells drupal what kind of element to build
			'#type' => 'textfield',
			// we want this field to be required
			'#required' => TRUE,
			// The "label" for this field
			// '#title' => t("Your email address"),
			// Optional description
			// '#description' => t('Must be a valid email address'),
			'#size' => 25 
	);
	
	$form ['fourdemUser_submit'] = array (
			'#type' => 'submit',
			// #value is the text to display inside the button
			'#value' => t ( 'Sign Up' ) 
	);
	
	return $form;
}

/**
 * Implementation of hook_form_validate() Drupal 7 function.
 * Define a validation function that drupal will automatically call when the submit button is pressed.
 * For this example, I will use the valid_email_address() function to verify that the email address looks proper: If it's not, we'll use form_set_error() function to tell drupal we didn't pass validation.
 */
function fourdemNewsletter_form_validate($form, &$form_state) {
	// Drupal stows away all of the form elements into
	// $form_state['values']. We find our 'friends_email'
	// element and assign it to a variable for easy
	// reference.
	$email = $form_state ['values'] ['fourdemUser_email'];
	
	// If it's not a valid email, set an error.
	if (valid_email_address ( $email ) == 0) {
		// form_set_error() tells drupal that it should not proceed.
		// The first parameter is the form element that didn't pass
		// validation. The second is the message to tell the user.
		form_set_error ( 'fourdemUser_email', t ( 'Not a valid email address' ) );
	}
}

/**
 * Implementation of hook_form_submit() Drupal 7 function.
 * Define a submit funciton that drupal will automatically call when submit is pressed (and all validators pass)
 */
function fourdemNewsletter_form_submit($form, &$form_state) {
	// Get the email value again
	$email = $form_state ['values'] ['fourdemUser_email'];
	
	// Now we call 4Dem API for user subscription
	$apiResponse = iscriviNewsletter ( $email );
	if (isset ( $apiResponse )) {
		if ($apiResponse->Success) {
			drupal_set_message ( t ( 'Thank you for your subscription!' ) );
		} else {
			if ($apiResponse->ErrorCode == 9) // Error for registered user
				drupal_set_message ( t ( 'The Email Address You have entered is already registered' ), 'error' );
		}
	}
}

/**
 * Custom 4marketing function: simply creates help content and send it back ;)
 */
function fourdemnews_help_creator() {
	$helpString = '';
	$helpString .= '<h3>' . t ( 'About this module' ) . '</h3>';
	$helpString .= '<p>' . t ( "This module allows you to integrate a site based on Drupal framework with the Advision-4Dem.it newsletter management console. Once configured subscribers' email addresses will be automatically saved into your 4Dem list." ) . '</p>';
	$helpString .= '<h3>' . t ( 'Configuration' ) . '</h3>';
	$helpString .= '<dl>';
	$helpString .= '<dt>' . t ( "Configure connection parameters" ) . '</dt>';
	$helpString .= '<dd>' . t ( "1. Click on '4Dem Newsletter' menu in order to open configuration page<br>2. Insert connection data provided by 4Dem. If you don't have ones visit <a href='http://www.4dem.it' target='_blank'>Advision - 4Dem website</a><br>3. Save the configuration in order to test the connection and retrieve console data" ) . '</dd>';
	$helpString .= '<dt>' . t ( "Select destination list for registered users" ) . '</dt>';
	$helpString .= '<dd>' . t ( "If the module has succesfully connected to 4Dem console you will be able to select one of your custom email lists from the drop down menu. Remember to <b>save configuration</b> in order to link the list!<br>One selected a list the configuration panel let's you to enabling auto synchronization and/or manual synching the repository." ) . '</dd>';
	$helpString .= '<dd>' . t ( "<i>Auto-synchronization</i>: every time a registered user confirm his email or change his email address, new/update infos are automatically stored into 4Dem console. Otherwise admin will have to schedule a manual synchronization in order to align 4Dem repository." ) . '</dd>';
	$helpString .= '<dd>' . t ( "<i>Manual Synchronization</i>: Clicking the button will cause the upload of all local users/email addres into destination list in remote 4Dem console." ) . '</dd>';
	$helpString .= '<dt>' . t ( "Select destination list for newsletter subscribers" ) . '</dt>';
	$helpString .= '<dd>' . t ( "If the module has succesfully connected to 4Dem console you will be able to select one of your custom email lists from the drop down menu. Remember to <b>save configuration</b> in order to link the list!" ) . '</dd>';
	$helpString .= '<dt>' . t ( "Publish the custom newsletter block" ) . '</dt>';
	$helpString .= '<dd>' . t ( "Publish 4Dem newsletter custom block in your site in orde to give a registration point to your users. Remember that is possible to change the default block title from standard block configuration panel" ) . '</dd>';
	$helpString .= '</dl>';
	return $helpString;
}